@@ -35,7 +35,7 @@
 #endif
 
 /* Define the canonical host system type as a string constant */
-#define CANONICAL_HOST_TYPE "i386-OpenBSD"
+#define CANONICAL_HOST_TYPE "mips64-OpenBSD"
 
 /* Define if char is unsigned on the C compiler */
 /* #undef C_CHAR_UNSIGNED */
@@ -56,6 +56,9 @@
 /* Define if we want a populated builtin dictionary */
 /* #undef ENABLE_BUILTIN_DICTIONARY */
 
+/* Define if we want load external dictionaries */
+#define ENABLE_EXTERNAL_DICTIONARY "1"
+
 /* Define the environment variable path separator */
 #define ENVIRONMENT_PATH_SEPARATOR ':'
 
@@ -837,16 +840,16 @@
 /* #undef PACKAGE_TARNAME */
 
 /* Define to the date of this package. */
-#define PACKAGE_DATE "2017-07-14"
+#define PACKAGE_DATE "2018-02-05"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "3.6.2"
+#define PACKAGE_VERSION "3.6.3"
 
 /* Define to the version suffix of this package. */
 #define PACKAGE_VERSION_SUFFIX ""
 
 /* Define to the version number of this package. */
-#define PACKAGE_VERSION_NUMBER 362
+#define PACKAGE_VERSION_NUMBER 363
 
 /* Define path separator */
 #define PATH_SEPARATOR '/'
@@ -877,13 +880,13 @@
 #define SIZEOF_INT 4
 
 /* The size of a `long', as computed by sizeof. */
-#define SIZEOF_LONG 4
+#define SIZEOF_LONG 8
 
 /* The size of a `short', as computed by sizeof. */
 #define SIZEOF_SHORT 2
 
 /* The size of a `void *', as computed by sizeof. */
-#define SIZEOF_VOID_P 4
+#define SIZEOF_VOID_P 8
 
 /* The size of a `fpos_t', as computed by sizeof. */
 #define SIZEOF_FPOS_T 8
@@ -936,7 +939,7 @@
 /* #undef ENABLE_PRIVATE_TAGS */
 
 /* Define if we are compiling with sndfile support. */
-/* #undef WITH_SNDFILE */
+#define WITH_SNDFILE
 
 /* Define if we are compiling with libwrap (TCP wrapper) support */
 /* #undef WITH_TCPWRAPPER */
@@ -1098,7 +1101,7 @@ typedef unsigned long ulong;
 #define STDIO_NAMESPACE ::
 
 /* Define if we can use C++11 */
-/* #undef HAVE_CXX11 */
+#define HAVE_CXX11 1
 
 #if defined(HAVE_CXX11) && defined(__cplusplus) && __cplusplus < 201103L
 #error\
