@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2017, OFFIS e.V.
+ *  Copyright (C) 1994-2018, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -682,7 +682,7 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      *  to even size needed for a buffer into which a frame is to be loaded.
      *  @param dataset dataset in which this pixel data element is contained
      *  @param frameSize frame size in bytes (without padding) returned in this
-     *    parameter upon success
+     *    parameter upon success, otherwise set to 0
      *  @return EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition getUncompressedFrameSize(DcmItem *dataset,
@@ -734,6 +734,17 @@ class DCMTK_DCMDATA_EXPORT DcmElement
     virtual OFCondition getDecompressedColorModel(DcmItem *dataset,
                                                   OFString &decompressedColorModel);
 
+    /** Determine if this element is universal matching.
+     *  @param normalize normalize each element value. Defaults to OFTrue.
+     *  @param enableWildCardMatching enable or disable wild card matching. Defaults to OFTrue,
+     *    which means wild card matching is performed if the element's VR supports it. Set to
+     *    OFFalse to force single value matching instead.
+     *  @return returns OFTrue if element is empty or if enableWildCardMatching is enabled and
+     *    the element contains only wildcard characters. Returns OFFalse otherwise.
+     */
+    virtual OFBool isUniversalMatch(const OFBool normalize = OFTrue,
+                                    const OFBool enableWildCardMatching = OFTrue);
+
     /** perform attribute matching.
      *  Perform attribute matching on a candidate element using this element as the matching
      *  key.
