@@ -51,6 +51,7 @@ END_EXTERN_C
  *------------------------*/
 
 class OFFilename;
+class OFSockAddr;
 
 /*---------------------*
  *  class declaration  *
@@ -80,7 +81,6 @@ class DCMTK_OFSTD_EXPORT OFStandard
         MM_XML
     };
 
-    class OFHostent;
     class OFGroup;
     class OFPasswd;
 
@@ -972,19 +972,22 @@ class DCMTK_OFSTD_EXPORT OFStandard
      */
     static void trimString( const char*& pBegin, const char*& pEnd );
 
-    /** Thread-safe version of gethostbyname.
-     *  @param name the host name.
-     *  @return a OFStandard::OFHostent object.
+    /** This function performs a reverse DNS lookup of a hostname.
+     *  The parameters are identical to those passed to gethostbyaddr().
+     *  If the lookup fails, an empty string is returned.
+     *  @param addr IP address, actually a pointer to a struct in_addr or a struct in6_addr object
+     *  @param len length of the struct pointed to by addr
+     *  @param type address type, either AF_INET or AF_INET6
+     *  @return hostname for the IP address
      */
-    static OFHostent getHostByName( const char* name );
+    static OFString getHostnameByAddress(const char* addr, int len, int type);
 
-    /** Thread-safe version of gethostbyaddr.
-     *  @param addr see manpage.
-     *  @param len see manpage.
-     *  @param type see manpage.
-     *  @return a OFStandard::OFHostent object.
+    /** This function performs a DNS lookup of an IP address based on a hostname.
+     *  If a DNS lookup yields multiple IP addresses, only the first one is returned.
+     *  @param name hostname
+     *  @param result a OFSockAddr instance in which the result is stored
      */
-    static OFHostent getHostByAddr( const char* addr, int len, int type );
+    static void getAddressByHostname(const char *name, OFSockAddr& result);
 
     /** Thread-safe version of getgrnam.
      *  @param name the group name.
